@@ -16,31 +16,42 @@
 #ifndef GANV_NODE_HPP
 #define GANV_NODE_HPP
 
-#include <glib.h>
-#include <assert.h>
-
-#include "ganv/node.h"
 #include "ganv/Item.hpp"
+#include "ganv/item.h"
+#include "ganv/node.h"
+#include "ganv/types.h"
+#include "ganv/wrap.hpp"
 
-GANV_GLIB_WRAP(Node)
+#include <glib-object.h>
+#include <glib.h>
+#include <glibmm/object.h>
+#include <gobject/gclosure.h>
+#include <sigc++/signal.h>
+
+GANV_GLIB_WRAP(Node) // IWYU pragma: keep
 
 namespace Ganv {
 
 class Canvas;
-class Node;
 
 /** An object a Edge can connect to.
  */
 class Node : public Item {
 public:
-	Node(Canvas* canvas, GanvNode* gobj)
+	Node(Canvas*, GanvNode* gobj)
 		: Item(GANV_ITEM(g_object_ref(gobj)))
 	{
 		g_signal_connect(gobj, "moved", G_CALLBACK(on_moved), this);
 		CONNECT_PROP_SIGNAL(gobj, selected, on_notify_bool, &Node::on_selected)
 	}
 
-	~Node() {
+	Node(const Node&) = delete;
+	Node& operator=(const Node&) = delete;
+
+	Node(Node&&) = delete;
+	Node& operator=(Node&&) = delete;
+
+	~Node() override {
 		g_object_unref(_gobj);
 	}
 
@@ -63,15 +74,18 @@ public:
 	RW_PROPERTY(gboolean, draggable)
 	RW_PROPERTY(gboolean, grabbed)
 
-	RW_OBJECT_PROPERTY(Node*, partner);
+	RW_OBJECT_PROPERTY(Node*, partner)
 
 	GanvNode*       gobj()       { return GANV_NODE(_gobj); }
 	const GanvNode* gobj() const { return GANV_NODE(_gobj); }
 
-	METHOD2(ganv_node, move, double, dx, double, dy)
+	void move(const double dx, const double dy) override {
+		ganv_node_move(gobj(), dx, dy);
+	}
+
 	METHOD2(ganv_node, move_to, double, x, double, y)
 
-	METHOD0(ganv_node, disconnect);
+	METHOD0(ganv_node, disconnect)
 
 	sigc::signal<void, double, double>& signal_moved() {
 		return _signal_moved;
@@ -88,16 +102,16 @@ private:
 	template<typename T>
 	static void on_notify(GObject* gobj, GParamSpec* pspec, gpointer signal) {
 		T value;
-		g_object_get(gobj, g_param_spec_get_name(pspec), &value, NULL);
+		g_object_get(gobj, g_param_spec_get_name(pspec), &value, nullptr);
 		((sigc::signal<bool, T>*)signal)->emit(value);
 	}
 	*/
 	static void on_notify_bool(GObject*    gobj,
 	                           GParamSpec* pspec,
 	                           gpointer    signal) {
-		gboolean value;
-		g_object_get(gobj, g_param_spec_get_name(pspec), &value, NULL);
-		((sigc::signal<bool, gboolean>*)signal)->emit(value);
+		gboolean value = FALSE;
+		g_object_get(gobj, g_param_spec_get_name(pspec), &value, nullptr);
+		static_cast<sigc::signal<bool, gboolean>*>(signal)->emit(value);
 	}
 };
 
