@@ -13,17 +13,23 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <string.h>
-
-#include <cairo.h>
+#include "boilerplate.h"
+#include "color.h"
+#include "ganv-private.h"
+#include "gettext.h"
 
 #include "ganv/box.h"
+#include "ganv/item.h"
+#include "ganv/node.h"
+#include "ganv/types.h"
 
-#include "./boilerplate.h"
-#include "./color.h"
-#include "./gettext.h"
-#include "./ganv-private.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <math.h>
+#include <string.h>
 
 static const double STACKED_OFFSET = 4.0;
 
@@ -49,7 +55,7 @@ enum {
 static void
 ganv_box_init(GanvBox* box)
 {
-	box->impl = ganv_box_get_instance_private(box);
+	box->impl = (GanvBoxPrivate*)ganv_box_get_instance_private(box);
 
 	memset(&box->impl->coords, '\0', sizeof(GanvBoxCoords));
 
@@ -87,16 +93,16 @@ ganv_box_set_property(GObject*      object,
 	GanvBoxCoords*  coords = &impl->coords;
 
 	switch (prop_id) {
-		SET_CASE(X1, double, coords->x1);
-		SET_CASE(Y1, double, coords->y1);
-		SET_CASE(X2, double, coords->x2);
-		SET_CASE(Y2, double, coords->y2);
-		SET_CASE(RADIUS_TL, double, impl->radius_tl);
-		SET_CASE(RADIUS_TR, double, impl->radius_tr);
-		SET_CASE(RADIUS_BR, double, impl->radius_br);
-		SET_CASE(RADIUS_BL, double, impl->radius_bl);
-		SET_CASE(STACKED, boolean, coords->stacked);
-		SET_CASE(BEVELED, boolean, impl->beveled);
+		SET_CASE(X1, double, coords->x1)
+		SET_CASE(Y1, double, coords->y1)
+		SET_CASE(X2, double, coords->x2)
+		SET_CASE(Y2, double, coords->y2)
+		SET_CASE(RADIUS_TL, double, impl->radius_tl)
+		SET_CASE(RADIUS_TR, double, impl->radius_tr)
+		SET_CASE(RADIUS_BR, double, impl->radius_br)
+		SET_CASE(RADIUS_BL, double, impl->radius_bl)
+		SET_CASE(STACKED, boolean, coords->stacked)
+		SET_CASE(BEVELED, boolean, impl->beveled)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -117,16 +123,16 @@ ganv_box_get_property(GObject*    object,
 	GanvBoxCoords*  coords = &impl->coords;
 
 	switch (prop_id) {
-		GET_CASE(X1, double, coords->x1);
-		GET_CASE(X2, double, coords->x2);
-		GET_CASE(Y1, double, coords->y1);
-		GET_CASE(Y2, double, coords->y2);
-		GET_CASE(RADIUS_TL, double, impl->radius_tl);
-		GET_CASE(RADIUS_TR, double, impl->radius_tr);
-		GET_CASE(RADIUS_BR, double, impl->radius_br);
-		GET_CASE(RADIUS_BL, double, impl->radius_bl);
-		GET_CASE(STACKED, boolean, impl->coords.stacked);
-		GET_CASE(BEVELED, boolean, impl->beveled);
+		GET_CASE(X1, double, coords->x1)
+		GET_CASE(X2, double, coords->x2)
+		GET_CASE(Y1, double, coords->y1)
+		GET_CASE(Y2, double, coords->y2)
+		GET_CASE(RADIUS_TL, double, impl->radius_tl)
+		GET_CASE(RADIUS_TR, double, impl->radius_tr)
+		GET_CASE(RADIUS_BR, double, impl->radius_br)
+		GET_CASE(RADIUS_BL, double, impl->radius_bl)
+		GET_CASE(STACKED, boolean, impl->coords.stacked)
+		GET_CASE(BEVELED, boolean, impl->beveled)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -149,7 +155,10 @@ ganv_box_request_redraw(GanvItem*            item,
                         const GanvBoxCoords* coords,
                         gboolean             world)
 {
-	double x1, y1, x2, y2;
+	double x1 = 0.0;
+	double y1 = 0.0;
+	double x2 = 0.0;
+	double y2 = 0.0;
 	ganv_box_bounds_item(coords, &x1, &y1, &x2, &y2);
 
 	if (!world) {
@@ -262,11 +271,16 @@ ganv_box_draw(GanvItem* item,
 	double y2 = impl->coords.y2;
 	ganv_item_i2w_pair(item, &x1, &y1, &x2, &y2);
 
-	double dash_length, border_color, fill_color;
+	double dash_length  = 0.0;
+	double border_color = 0.0;
+	double fill_color   = 0.0;
 	ganv_node_get_draw_properties(
 		&box->node, &dash_length, &border_color, &fill_color);
 
-	double r, g, b, a;
+	double r = 0.0;
+	double g = 0.0;
+	double b = 0.0;
+	double a = 0.0;
 
 	for (int i = (impl->coords.stacked ? 1 : 0); i >= 0; --i) {
 		const double x = 0.0 - (STACKED_OFFSET * i);
@@ -308,7 +322,10 @@ ganv_box_point(GanvItem* item, double x, double y, GanvItem** actual_item)
 
 	*actual_item = NULL;
 
-	double x1, y1, x2, y2;
+	double x1 = 0.0;
+	double y1 = 0.0;
+	double x2 = 0.0;
+	double y2 = 0.0;
 	ganv_box_bounds_item(&impl->coords, &x1, &y1, &x2, &y2);
 
 	// Point is inside the box (distance 0)
@@ -345,7 +362,10 @@ ganv_box_is_within(const GanvNode* self,
                    double          x2,
                    double          y2)
 {
-	double bx1, by1, bx2, by2;
+	double bx1 = 0.0;
+	double by1 = 0.0;
+	double bx2 = 0.0;
+	double by2 = 0.0;
 	g_object_get(G_OBJECT(self),
 	             "x1", &bx1,
 	             "y1", &by1,
