@@ -13,16 +13,27 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <string.h>
+#include "boilerplate.h"
+#include "color.h"
+#include "ganv-private.h"
+#include "gettext.h"
 
 #include "ganv/canvas.h"
 #include "ganv/circle.h"
+#include "ganv/item.h"
+#include "ganv/node.h"
+#include "ganv/text.h"
+#include "ganv/types.h"
 
-#include "./color.h"
-#include "./boilerplate.h"
-#include "./gettext.h"
-#include "./ganv-private.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <float.h>
+#include <math.h>
+#include <stdarg.h>
+#include <string.h>
 
 G_DEFINE_TYPE_WITH_CODE(GanvCircle, ganv_circle, GANV_TYPE_NODE,
                         G_ADD_PRIVATE(GanvCircle))
@@ -39,7 +50,7 @@ enum {
 static void
 ganv_circle_init(GanvCircle* circle)
 {
-	circle->impl = ganv_circle_get_instance_private(circle);
+	circle->impl = (GanvCirclePrivate*)ganv_circle_get_instance_private(circle);
 
 	memset(&circle->impl->coords, '\0', sizeof(GanvCircleCoords));
 	circle->impl->coords.radius     = 0.0;
@@ -72,9 +83,9 @@ ganv_circle_set_property(GObject*      object,
 	GanvCircle* circle = GANV_CIRCLE(object);
 
 	switch (prop_id) {
-		SET_CASE(RADIUS, double, circle->impl->coords.radius);
-		SET_CASE(RADIUS_EMS, double, circle->impl->coords.radius_ems);
-		SET_CASE(FIT_LABEL, boolean, circle->impl->fit_label);
+		SET_CASE(RADIUS, double, circle->impl->coords.radius)
+		SET_CASE(RADIUS_EMS, double, circle->impl->coords.radius_ems)
+		SET_CASE(FIT_LABEL, boolean, circle->impl->fit_label)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -97,9 +108,9 @@ ganv_circle_get_property(GObject*    object,
 	GanvCircle* circle = GANV_CIRCLE(object);
 
 	switch (prop_id) {
-		GET_CASE(RADIUS, double, circle->impl->coords.radius);
-		GET_CASE(RADIUS_EMS, double, circle->impl->coords.radius_ems);
-		GET_CASE(FIT_LABEL, boolean, circle->impl->fit_label);
+		GET_CASE(RADIUS, double, circle->impl->coords.radius)
+		GET_CASE(RADIUS_EMS, double, circle->impl->coords.radius_ems)
+		GET_CASE(FIT_LABEL, boolean, circle->impl->fit_label)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -287,13 +298,18 @@ ganv_circle_draw(GanvItem* item,
 	GanvCircle*        circle = GANV_CIRCLE(item);
 	GanvCirclePrivate* impl   = circle->impl;
 
-	double r, g, b, a;
+	double r = 0.0;
+	double g = 0.0;
+	double b = 0.0;
+	double a = 0.0;
 
 	double x = impl->coords.x;
 	double y = impl->coords.y;
 	ganv_item_i2w(item, &x, &y);
 
-	double dash_length, border_color, fill_color;
+	double dash_length  = 0.0;
+	double border_color = 0.0;
+	double fill_color   = 0.0;
 	ganv_node_get_draw_properties(
 		&circle->node, &dash_length, &border_color, &fill_color);
 
