@@ -13,21 +13,25 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <string.h>
-
-#include <cairo.h>
+#include "boilerplate.h"
+#include "color.h"
+#include "ganv-private.h"
+#include "gettext.h"
 
 #include "ganv/canvas.h"
 #include "ganv/edge.h"
+#include "ganv/item.h"
 #include "ganv/node.h"
+#include "ganv/types.h"
 
-#include "./boilerplate.h"
-#include "./color.h"
-#include "./gettext.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <stdarg.h>
 
-#include "color.h"
-#include "ganv-private.h"
+#include <math.h>
+#include <string.h>
 
 #define ARROW_DEPTH   32
 #define ARROW_BREADTH 32
@@ -63,7 +67,8 @@ static GanvItemClass* parent_class;
 static void
 ganv_edge_init(GanvEdge* edge)
 {
-	GanvEdgePrivate* impl = ganv_edge_get_instance_private(edge);
+	GanvEdgePrivate* impl =
+	    (GanvEdgePrivate*)ganv_edge_get_instance_private(edge);
 
 	edge->impl = impl;
 
@@ -116,17 +121,17 @@ ganv_edge_set_property(GObject*      object,
 	GanvEdgeCoords*  coords = &impl->coords;
 
 	switch (prop_id) {
-		SET_CASE(WIDTH, double, coords->width);
-		SET_CASE(HANDLE_RADIUS, double, coords->handle_radius);
-		SET_CASE(DASH_LENGTH, double, impl->dash_length);
-		SET_CASE(DASH_OFFSET, double, impl->dash_offset);
-		SET_CASE(COLOR, uint, impl->color);
-		SET_CASE(CONSTRAINING, boolean, impl->coords.constraining);
-		SET_CASE(CURVED, boolean, impl->coords.curved);
-		SET_CASE(ARROWHEAD, boolean, impl->coords.arrowhead);
-		SET_CASE(SELECTED, boolean, impl->selected);
-		SET_CASE(HIGHLIGHTED, boolean, impl->highlighted);
-		SET_CASE(GHOST, boolean, impl->ghost);
+		SET_CASE(WIDTH, double, coords->width)
+		SET_CASE(HANDLE_RADIUS, double, coords->handle_radius)
+		SET_CASE(DASH_LENGTH, double, impl->dash_length)
+		SET_CASE(DASH_OFFSET, double, impl->dash_offset)
+		SET_CASE(COLOR, uint, impl->color)
+		SET_CASE(CONSTRAINING, boolean, impl->coords.constraining)
+		SET_CASE(CURVED, boolean, impl->coords.curved)
+		SET_CASE(ARROWHEAD, boolean, impl->coords.arrowhead)
+		SET_CASE(SELECTED, boolean, impl->selected)
+		SET_CASE(HIGHLIGHTED, boolean, impl->highlighted)
+		SET_CASE(GHOST, boolean, impl->ghost)
 	case PROP_TAIL: {
 		const gobject tmp = g_value_get_object(value);
 		if (impl->tail != tmp) {
@@ -162,19 +167,19 @@ ganv_edge_get_property(GObject*    object,
 	GanvEdgePrivate* impl = edge->impl;
 
 	switch (prop_id) {
-		GET_CASE(TAIL, object, impl->tail);
-		GET_CASE(HEAD, object, impl->head);
-		GET_CASE(WIDTH, double, impl->coords.width);
-		SET_CASE(HANDLE_RADIUS, double, impl->coords.handle_radius);
-		GET_CASE(DASH_LENGTH, double, impl->dash_length);
-		GET_CASE(DASH_OFFSET, double, impl->dash_offset);
-		GET_CASE(COLOR, uint, impl->color);
-		GET_CASE(CONSTRAINING, boolean, impl->coords.constraining);
-		GET_CASE(CURVED, boolean, impl->coords.curved);
-		GET_CASE(ARROWHEAD, boolean, impl->coords.arrowhead);
-		GET_CASE(SELECTED, boolean, impl->selected);
-		GET_CASE(HIGHLIGHTED, boolean, impl->highlighted);
-		SET_CASE(GHOST, boolean, impl->ghost);
+		GET_CASE(TAIL, object, impl->tail)
+		GET_CASE(HEAD, object, impl->head)
+		GET_CASE(WIDTH, double, impl->coords.width)
+		SET_CASE(HANDLE_RADIUS, double, impl->coords.handle_radius)
+		GET_CASE(DASH_LENGTH, double, impl->dash_length)
+		GET_CASE(DASH_OFFSET, double, impl->dash_offset)
+		GET_CASE(COLOR, uint, impl->color)
+		GET_CASE(CONSTRAINING, boolean, impl->coords.constraining)
+		GET_CASE(CURVED, boolean, impl->coords.curved)
+		GET_CASE(ARROWHEAD, boolean, impl->coords.arrowhead)
+		GET_CASE(SELECTED, boolean, impl->selected)
+		GET_CASE(HIGHLIGHTED, boolean, impl->highlighted)
+		SET_CASE(GHOST, boolean, impl->ghost)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -311,7 +316,10 @@ ganv_edge_update(GanvItem* item, int flags)
 	impl->old_coords = impl->coords;
 
 	// Get bounding box
-	double x1, x2, y1, y2;
+	double x1 = 0.0;
+	double x2 = 0.0;
+	double y1 = 0.0;
+	double y2 = 0.0;
 	ganv_edge_bounds(item, &x1, &y1, &x2, &y2);
 
 	// Ensure bounding box has non-zero area
@@ -339,6 +347,11 @@ static void
 ganv_edge_draw(GanvItem* item,
                cairo_t* cr, double cx, double cy, double cw, double ch)
 {
+	(void)cx;
+	(void)cy;
+	(void)cw;
+	(void)ch;
+
 	GanvEdge*        edge = GANV_EDGE(item);
 	GanvEdgePrivate* impl = edge->impl;
 
@@ -349,7 +362,10 @@ ganv_edge_draw(GanvItem* item,
 	double dx    = src_x - dst_x;
 	double dy    = src_y - dst_y;
 
-	double r, g, b, a;
+	double r = 0.0;
+	double g = 0.0;
+	double b = 0.0;
+	double a = 0.0;
 	if (impl->highlighted) {
 		color_to_rgba(highlight_color(impl->color, 0x40), &r, &g, &b, &a);
 	} else {
