@@ -20,12 +20,17 @@
 extern "C" {
 #endif
 
-#include <cairo.h>
-
 #include "ganv/canvas.h"
+#include "ganv/item.h"
 #include "ganv/text.h"
 #include "ganv/types.h"
 
+#include <cairo.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <pango/pango-layout.h>
+
 #define GANV_CLOSE_ENOUGH 1
 
 extern guint signal_moved;
