@@ -13,18 +13,28 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <stdlib.h>
-#include <string.h>
+#include "ganv-private.h"
 
+#include "ganv/box.h"
 #include "ganv/canvas.h"
+#include "ganv/item.h"
 #include "ganv/module.h"
+#include "ganv/node.h"
 #include "ganv/port.h"
+#include "ganv/text.h"
+#include "ganv/types.h"
 #include "ganv/widget.h"
 
-#include "./color.h"
-#include "./boilerplate.h"
-#include "./gettext.h"
-#include "./ganv-private.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gobject/gclosure.h>
+#include <gtk/gtk.h>
+
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #define FOREACH_PORT(ports, i) \
 	for (GanvPort** i = (GanvPort**)ports->pdata; \
@@ -50,7 +60,8 @@ enum {
 static void
 ganv_module_init(GanvModule* module)
 {
-	GanvModulePrivate* impl = ganv_module_get_instance_private(module);
+	GanvModulePrivate* impl =
+	    (GanvModulePrivate*)ganv_module_get_instance_private(module);
 
 	module->impl = impl;
 
@@ -99,6 +110,8 @@ ganv_module_set_property(GObject*      object,
                          const GValue* value,
                          GParamSpec*   pspec)
 {
+	(void)value;
+
 	g_return_if_fail(object != NULL);
 	g_return_if_fail(GANV_IS_MODULE(object));
 
@@ -115,6 +128,8 @@ ganv_module_get_property(GObject*    object,
                          GValue*     value,
                          GParamSpec* pspec)
 {
+	(void)value;
+
 	g_return_if_fail(object != NULL);
 	g_return_if_fail(GANV_IS_MODULE(object));
 
@@ -152,7 +167,8 @@ measure(GanvModule* module, Metrics* m)
 {
 	memset(m, '\0', sizeof(Metrics));
 
-	double title_w, title_h;
+	double title_w = 0.0;
+	double title_h = 0.0;
 	title_size(module, &title_w, &title_h);
 
 	GanvCanvas*        canvas       = ganv_item_get_canvas(GANV_ITEM(module));
@@ -253,7 +269,8 @@ place_title(GanvModule* module, GanvDirection dir)
 	GanvBox*  box          = GANV_BOX(module);
 	GanvText* canvas_title = GANV_NODE(module)->impl->label;
 
-	double title_w, title_h;
+	double title_w = 0.0;
+	double title_h = 0.0;
 	title_size(module, &title_w, &title_h);
 
 	if (!canvas_title) {
@@ -279,7 +296,8 @@ resize_right(GanvModule* module)
 	Metrics m;
 	measure(module, &m);
 
-	double title_w, title_h;
+	double title_w = 0.0;
+	double title_h = 0.0;
 	title_size(module, &title_w, &title_h);
 
 	// Basic height contains title
@@ -355,7 +373,8 @@ resize_down(GanvModule* module)
 	Metrics m;
 	measure(module, &m);
 
-	double title_w, title_h;
+	double title_w = 0.0;
+	double title_h = 0.0;
 	title_size(module, &title_w, &title_h);
 
 	const double port_depth   = ganv_module_get_empty_port_depth(module);
@@ -806,7 +825,8 @@ ganv_module_embed(GanvModule* module,
 		return;
 	}
 
-	double title_w, title_h;
+	double title_w = 0.0;
+	double title_h = 0.0;
 	title_size(module, &title_w, &title_h);
 
 	impl->embed_item = ganv_item_new(
