@@ -13,17 +13,30 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <stdlib.h>
+#include "boilerplate.h"
+#include "color.h"
+#include "ganv-private.h"
+#include "gettext.h"
 
+#include "ganv/box.h"
 #include "ganv/canvas.h"
-#include "ganv/port.h"
+#include "ganv/edge.h"
+#include "ganv/item.h"
 #include "ganv/module.h"
+#include "ganv/node.h"
+#include "ganv/port.h"
+#include "ganv/text.h"
+#include "ganv/types.h"
 
-#include "./boilerplate.h"
-#include "./color.h"
-#include "./ganv-private.h"
-#include "./gettext.h"
+#include <cairo.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <math.h>
+#include <stdarg.h>
+#include <stdlib.h>
 
 static const double PORT_LABEL_HPAD = 4.0;
 static const double PORT_LABEL_VPAD = 1.0;
@@ -52,7 +65,7 @@ static guint port_signals[PORT_LAST_SIGNAL];
 static void
 ganv_port_init(GanvPort* port)
 {
-	port->impl = ganv_port_get_instance_private(port);
+	port->impl = (GanvPortPrivate*)ganv_port_get_instance_private(port);
 
 	port->impl->control         = NULL;
 	port->impl->value_label     = NULL;
@@ -96,8 +109,8 @@ ganv_port_set_property(GObject*      object,
 	GanvPort* port = GANV_PORT(object);
 
 	switch (prop_id) {
-		SET_CASE(IS_INPUT, boolean, port->impl->is_input);
-		SET_CASE(IS_CONTROLLABLE, boolean, port->impl->is_controllable);
+		SET_CASE(IS_INPUT, boolean, port->impl->is_input)
+		SET_CASE(IS_CONTROLLABLE, boolean, port->impl->is_controllable)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -116,8 +129,8 @@ ganv_port_get_property(GObject*    object,
 	GanvPort* port = GANV_PORT(object);
 
 	switch (prop_id) {
-		GET_CASE(IS_INPUT, boolean, port->impl->is_input);
-		GET_CASE(IS_CONTROLLABLE, boolean, port->impl->is_controllable);
+		GET_CASE(IS_INPUT, boolean, port->impl->is_input)
+		GET_CASE(IS_CONTROLLABLE, boolean, port->impl->is_controllable)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -197,6 +210,8 @@ ganv_port_tail_vector(const GanvNode* self,
                       double*         dx,
                       double*         dy)
 {
+	(void)head;
+
 	GanvPort*   port   = GANV_PORT(self);
 	GanvItem*   item   = &port->box.node.item;
 	GanvCanvas* canvas = ganv_item_get_canvas(item);
@@ -231,6 +246,8 @@ ganv_port_head_vector(const GanvNode* self,
                       double*         dx,
                       double*         dy)
 {
+	(void)tail;
+
 	GanvPort*   port   = GANV_PORT(self);
 	GanvItem*   item   = &port->box.node.item;
 	GanvCanvas* canvas = ganv_item_get_canvas(item);
@@ -682,7 +699,7 @@ ganv_port_get_natural_width(const GanvPort* port)
 	if (ganv_canvas_get_direction(canvas) == GANV_DIRECTION_DOWN) {
 		w = ganv_module_get_empty_port_breadth(ganv_port_get_module(port));
 	} else if (label && (GANV_ITEM(label)->object.flags & GANV_ITEM_VISIBLE)) {
-		double label_w;
+		double label_w = 0.0;
 		g_object_get(port->box.node.impl->label, "width", &label_w, NULL);
 		w = label_w + (PORT_LABEL_HPAD * 2.0);
 	} else {
@@ -691,7 +708,7 @@ ganv_port_get_natural_width(const GanvPort* port)
 	if (port->impl->value_label &&
 	    (GANV_ITEM(port->impl->value_label)->object.flags
 	     & GANV_ITEM_VISIBLE)) {
-		double label_w;
+		double label_w = 0.0;
 		g_object_get(port->impl->value_label, "width", &label_w, NULL);
 		w += label_w + PORT_LABEL_HPAD;
 	}
