@@ -13,20 +13,30 @@
  * with Ganv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <gtk/gtkstyle.h>
+#include "boilerplate.h"
+#include "color.h"
+#include "ganv-private.h"
+#include "gettext.h"
 
 #include "ganv/canvas.h"
+#include "ganv/item.h"
+#include "ganv/node.h"
 #include "ganv/text.h"
+#include "ganv/types.h"
 
-#include "./color.h"
-#include "./boilerplate.h"
-#include "./gettext.h"
-#include "./ganv-private.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <pango/pango-font.h>
+#include <pango/pango-fontmap.h>
+#include <pango/pango-layout.h>
+#include <pango/pango-types.h>
+#include <pango/pangocairo.h>
+
+#include <math.h>
+#include <stdlib.h>
+#include <string.h>
 
 G_DEFINE_TYPE_WITH_CODE(GanvText, ganv_text, GANV_TYPE_ITEM,
                         G_ADD_PRIVATE(GanvText))
@@ -47,7 +57,8 @@ enum {
 static void
 ganv_text_init(GanvText* text)
 {
-	GanvTextPrivate* impl = ganv_text_get_instance_private(text);
+	GanvTextPrivate* impl =
+	    (GanvTextPrivate*)ganv_text_get_instance_private(text);
 
 	text->impl = impl;
 
@@ -117,7 +128,8 @@ ganv_text_layout(GanvText* text)
 	cairo_font_options_destroy(opt);
 	pango_font_description_free(font);
 
-	int width, height;
+	int width  = 0;
+	int height = 0;
 	pango_layout_get_pixel_size(impl->layout, &width, &height);
 
 	impl->coords.width  = width;
@@ -188,12 +200,12 @@ ganv_text_get_property(GObject*    object,
 	}
 
 	switch (prop_id) {
-		GET_CASE(TEXT, string, impl->text);
-		GET_CASE(X, double, impl->coords.x);
-		GET_CASE(Y, double, impl->coords.y);
-		GET_CASE(WIDTH, double, impl->coords.width);
-		GET_CASE(HEIGHT, double, impl->coords.height);
-		GET_CASE(COLOR, uint, impl->color);
+		GET_CASE(TEXT, string, impl->text)
+		GET_CASE(X, double, impl->coords.x)
+		GET_CASE(Y, double, impl->coords.y)
+		GET_CASE(WIDTH, double, impl->coords.width)
+		GET_CASE(HEIGHT, double, impl->coords.height)
+		GET_CASE(COLOR, uint, impl->color)
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -244,14 +256,18 @@ ganv_text_point(GanvItem* item, double x, double y, GanvItem** actual_item)
 {
 	*actual_item = NULL;
 
-	double x1, y1, x2, y2;
+	double x1 = 0.0;
+	double y1 = 0.0;
+	double x2 = 0.0;
+	double y2 = 0.0;
 	ganv_text_bounds_item(item, &x1, &y1, &x2, &y2);
 	if ((x >= x1) && (y >= y1) && (x <= x2) && (y <= y2)) {
 		return 0.0;
 	}
 
 	// Point is outside the box
-	double dx, dy;
+	double dx = 0.0;
+	double dy = 0.0;
 
 	// Find horizontal distance to nearest edge
 	if (x < x1) {
@@ -278,6 +294,11 @@ static void
 ganv_text_draw(GanvItem* item,
                cairo_t* cr, double cx, double cy, double cw, double ch)
 {
+	(void)cx;
+	(void)cy;
+	(void)cw;
+	(void)ch;
+
 	GanvText*        text = GANV_TEXT(item);
 	GanvTextPrivate* impl = text->impl;
 
@@ -289,7 +310,10 @@ ganv_text_draw(GanvItem* item,
 		ganv_text_layout(text);
 	}
 
-	double r, g, b, a;
+	double r = 0.0;
+	double g = 0.0;
+	double b = 0.0;
+	double a = 0.0;
 	color_to_rgba(impl->color, &r, &g, &b, &a);
 
 	cairo_set_source_rgba(cr, r, g, b, a);
