@@ -17,15 +17,22 @@
  * Copyright 1997-2000 Free Software Foundation
  */
 
-#include <math.h>
-
-#include <gtk/gtksignal.h>
+#include "ganv-private.h"
+#include "gettext.h"
 
 #include "ganv/canvas.h"
+#include "ganv/item.h"
 #include "ganv/widget.h"
 
-#include "./gettext.h"
-#include "./ganv-private.h"
+#include <cairo.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gobject/gclosure.h>
+#include <gtk/gtk.h>
+#include <gtk/gtktypebuiltins.h>
+
+#include <math.h>
+#include <stddef.h>
 
 G_DEFINE_TYPE_WITH_CODE(GanvWidget, ganv_widget, GANV_TYPE_ITEM,
                         G_ADD_PRIVATE(GanvWidget))
@@ -46,7 +53,8 @@ enum {
 static void
 ganv_widget_init(GanvWidget* witem)
 {
-	GanvWidgetPrivate* impl = ganv_widget_get_instance_private(witem);
+	GanvWidgetPrivate* impl =
+	    (GanvWidgetPrivate*)ganv_widget_get_instance_private(witem);
 
 	witem->impl              = impl;
 	witem->impl->x           = 0.0;
@@ -134,7 +142,8 @@ recalc_bounds(GanvWidget* witem)
 	item->impl->x2 = witem->impl->cx + witem->impl->cwidth;
 	item->impl->y2 = witem->impl->cy + witem->impl->cheight;
 
-	int zoom_xofs, zoom_yofs;
+	int zoom_xofs = 0;
+	int zoom_yofs = 0;
 	ganv_canvas_get_zoom_offsets(item->impl->canvas, &zoom_xofs, &zoom_yofs);
 	if (witem->impl->widget) {
 		gtk_layout_move(GTK_LAYOUT(item->impl->canvas), witem->impl->widget,
@@ -146,6 +155,8 @@ recalc_bounds(GanvWidget* witem)
 static void
 do_destroy(GtkObject* object, gpointer data)
 {
+	(void)object;
+
 	GanvWidget* witem = GANV_WIDGET(data);
 
 	witem->impl->in_destroy = TRUE;
@@ -162,7 +173,7 @@ ganv_widget_set_property(GObject*      object,
 	GanvWidget* witem       = GANV_WIDGET(object);
 	int         update      = FALSE;
 	int         calc_bounds = FALSE;
-	GObject*    obj;
+	GObject*    obj         = NULL;
 
 	switch (param_id) {
 	case PROP_WIDGET:
@@ -177,7 +188,8 @@ ganv_widget_set_property(GObject*      object,
 			witem->impl->destroy_id = g_signal_connect(obj, "destroy",
 			                                     G_CALLBACK(do_destroy),
 			                                     witem);
-			int zoom_xofs, zoom_yofs;
+			int zoom_xofs = 0;
+			int zoom_yofs = 0;
 			ganv_canvas_get_zoom_offsets(item->impl->canvas, &zoom_xofs, &zoom_yofs);
 
 			gtk_layout_put(GTK_LAYOUT(item->impl->canvas), witem->impl->widget,
@@ -322,6 +334,12 @@ static void
 ganv_widget_draw(GanvItem* item,
                  cairo_t* cr, double cx, double cy, double cw, double ch)
 {
+	(void)cr;
+	(void)cx;
+	(void)cy;
+	(void)cw;
+	(void)ch;
+
 	GanvWidget* witem = GANV_WIDGET(item);
 
 	if (witem->impl->widget) {
@@ -336,7 +354,8 @@ ganv_widget_point(GanvItem* item, double x, double y, GanvItem** actual_item)
 
 	*actual_item = item;
 
-	double x1, y1;
+	double x1 = 0.0;
+	double y1 = 0.0;
 	ganv_canvas_c2w(item->impl->canvas, witem->impl->cx, witem->impl->cy, &x1, &y1);
 
 	const double pixels_per_unit = ganv_canvas_get_zoom(item->impl->canvas);
@@ -352,7 +371,7 @@ ganv_widget_point(GanvItem* item, double x, double y, GanvItem** actual_item)
 
 	/* Point is outside widget bounds */
 
-	double dx;
+	double dx = 0.0;
 	if (x < x1) {
 		dx = x1 - x;
 	} else if (x > x2) {
@@ -361,7 +380,7 @@ ganv_widget_point(GanvItem* item, double x, double y, GanvItem** actual_item)
 		dx = 0.0;
 	}
 
-	double dy;
+	double dy = 0.0;
 	if (y < y1) {
 		dy = y1 - y;
 	} else if (y > y2) {
