@@ -21,6 +21,8 @@ def get_project_info(top=None):
     """Load wscript to get project information (name, version, and so on)"""
 
     import importlib
+    import importlib.machinery
+    import importlib.util
 
     project_dir = top or os.getcwd()
     wscript_path = os.path.join(project_dir, "wscript")
@@ -422,8 +424,9 @@ def write_posts(entries, out_dir, meta={}):
     info = get_project_info()
     description = get_blurb("README.md")
     title = info["title"]
-    meta["Tags"] = ", ".join(info["post_tags"])
     meta["Author"] = meta.get("Author", os.getenv("USER"))
+    if info["post_tags"]:
+        meta["Tags"] = ", ".join(info["post_tags"])
 
     try:
         os.mkdir(out_dir)
